@@ -1,14 +1,15 @@
-from typing import TypeVar, Dict
+from typing import TypeVar, Dict, Generic
 
-import loguru
 from apscheduler.triggers.base import BaseTrigger
 
-from web_foundation.kernel.messaging.channel import IMessage, IChannel
 from web_foundation.extentions.schedulle.scheduller import TaskIMessage, BackgroundTask, TaskErrorCallback
+from web_foundation.kernel.container import GenericDependencyContainer
+from web_foundation.kernel.messaging.channel import IMessage, IChannel
 
 
-class Service:
+class Service(Generic[GenericDependencyContainer]):
     channel: IChannel
+    container: GenericDependencyContainer
 
     async def run_background(self, task: BackgroundTask,
                              *args,
